pub struct LiveSuccessForModule {
pub id: Uuid,
pub credit: RecordedCredit,
}Expand description
Another live attempt, of any completion of the same student and module, that the study registry already holds.
Fields
id: Uuidcredit: RecordedCreditTrait Implementations
Sourceimpl Clone for LiveSuccessForModule
impl Clone for LiveSuccessForModule
Sourcefn clone(&self) -> LiveSuccessForModule
fn clone(&self) -> LiveSuccessForModule
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for LiveSuccessForModule
impl RefUnwindSafe for LiveSuccessForModule
impl Send for LiveSuccessForModule
impl Sync for LiveSuccessForModule
impl Unpin for LiveSuccessForModule
impl UnsafeUnpin for LiveSuccessForModule
impl UnwindSafe for LiveSuccessForModule